package ru.csasq.cit_is_bot.ui.dialogs

import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.rememberScrollState
import androidx.compose.foundation.verticalScroll
import androidx.compose.material3.Button
import androidx.compose.material3.DropdownMenu
import androidx.compose.material3.DropdownMenuItem
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Text
import androidx.compose.material3.TopAppBar
import androidx.compose.runtime.Composable
import androidx.compose.runtime.MutableState
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.ui.Modifier
import androidx.compose.ui.text.style.TextOverflow
import androidx.compose.ui.unit.dp
import androidx.compose.ui.window.Dialog
import androidx.compose.ui.window.DialogProperties
import cit_is_bot.composeapp.generated.resources.Res
import cit_is_bot.composeapp.generated.resources.baseline_chat_24
import cit_is_bot.composeapp.generated.resources.baseline_close_24
import cit_is_bot.composeapp.generated.resources.baseline_more_vert_24
import org.jetbrains.compose.resources.painterResource
import ru.csasq.cit_is_bot.ui.screens.Scenario

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun ScenarioDialog(
    scenarioDialogState: MutableState<Scenario?>,
    properties: DialogProperties = DialogProperties(
        usePlatformDefaultWidth = false,
    ),
) {
    Dialog(
        onDismissRequest = {
            scenarioDialogState.value = null
        },
        properties = properties,
    ) {
        Scaffold(
            modifier = Modifier
                .fillMaxSize(),
            topBar = {
                TopAppBar(
                    title = {
                        Text(
                            text = scenarioDialogState.value?.id?.let {
                                "Изменить сценарий"
                            } ?: "Добавить сценарий",
                            overflow = TextOverflow.Ellipsis,
                            maxLines = 1,
                        )
                    },
                    navigationIcon = {
                        IconButton(
                            onClick = {
                                scenarioDialogState.value = null
                            },
                        ) {
                            Icon(
                                painter = painterResource(Res.drawable.baseline_close_24),
                                contentDescription = null,
                            )
                        }
                    },
                    actions = {
                        Button(
                            onClick = {
                                scenarioDialogState.value = null
                            },
                        ) {
                            Text(
                                text = "Сохранить",
                            )
                        }
                        val dropdownMenuState = remember {
                            mutableStateOf(false)
                        }
                        IconButton(
                            onClick = {
                                dropdownMenuState.value = true
                            },
                        ) {
                            Icon(
                                painter = painterResource(Res.drawable.baseline_more_vert_24),
                                contentDescription = null,
                            )
                        }
                        DropdownMenu(
                            expanded = dropdownMenuState.value,
                            onDismissRequest = {
                                dropdownMenuState.value = false
                            },
                        ) {
                            scenarioDialogState.value?.let {
                                DropdownMenuItem(
                                    text = {
                                        Text(
                                            text = "Удалить",
                                        )
                                    },
                                    onClick = {
                                        dropdownMenuState.value = false
                                    },
                                )
                            }
                            DropdownMenuItem(
                                text = {
                                    Text(
                                        text = "Сообщить о проблеме",
                                    )
                                },
                                onClick = {
                                    dropdownMenuState.value = false
                                },
                            )
                            DropdownMenuItem(
                                text = {
                                    Text(
                                        text = "Справка",
                                    )
                                },
                                onClick = {
                                    dropdownMenuState.value = false
                                },
                            )
                        }
                    },
                )
            },
        ) {
            Column(
                modifier = Modifier
                    .fillMaxSize()
                    .verticalScroll(
                        state = rememberScrollState(),
                    )
                    .padding(it)
                    .padding(
                        horizontal = 16.dp,
                    ),
            ) {

            }
        }
    }
}