package ru.csasq.cit_is_bot.ui.screens

import androidx.compose.foundation.ScrollState
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.PaddingValues
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.rememberScrollState
import androidx.compose.foundation.verticalScroll
import androidx.compose.runtime.Composable
import androidx.compose.runtime.MutableState
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.ui.Modifier
import androidx.compose.ui.geometry.Offset
import androidx.compose.ui.input.nestedscroll.NestedScrollConnection
import androidx.compose.ui.input.nestedscroll.NestedScrollSource
import androidx.compose.ui.input.nestedscroll.nestedScroll
import androidx.compose.ui.text.buildAnnotatedString
import androidx.navigation.NavController
import ru.csasq.cit_is_bot.ui.components.SwitchButton
import ru.csasq.cit_is_bot.ui.dialogs.ScenarioDialog

data class Scenario(
    val id: Int? = null,
    val name: String,
    val daysOfWeek: String,
    val time: String,
    val messageNumber: String,
    val isEnabled: Boolean,
)

val scenarioList = listOf(
    Scenario(1, "Текущее состояние сотрудников", "ПН-ПТ", "11:00", "1 сообщение", true),
    Scenario(2, "Планы на обед", "ПН-ПТ", "11:45-12:00", "2 сообщения", false),
)

@Composable
fun ScenariosScreen(
    navController: NavController,
    paddingValues: PaddingValues,
    floatingActionButtonOnClickState: MutableState<(() -> Unit)?>,
    floatingActionButtonExpandedState: MutableState<Boolean>,
) {
    Column(
        modifier = Modifier
            .padding(
                paddingValues = paddingValues,
            )
            .fillMaxSize()
            .verticalScroll(
                state = rememberScrollState(),
            ),
    ) {
        val scenarioDialogState = remember {
            mutableStateOf<Scenario?>(null)
        }
        floatingActionButtonOnClickState.value = {
            scenarioDialogState.value = Scenario(
                name = "",
                daysOfWeek = "",
                time = "",
                messageNumber = "",
                isEnabled = true,
            )
        }
        scenarioList.forEach {
            val scenarioSwitchState = remember {
                mutableStateOf(it.isEnabled)
            }
            val captionAnnotatedString = buildAnnotatedString {
                append(it.daysOfWeek)
                append(" \u2022 ")
                append(it.time)
                append(" \u2022 ")
                append(it.messageNumber)
            }
            SwitchButton(
                title = it.name,
                caption = captionAnnotatedString.text,
                switchState = scenarioSwitchState,
                onCheckedChange = { value ->
                    scenarioSwitchState.value = value
                },
                onClick = {
                    scenarioDialogState.value = it
                },
            )
        }

        scenarioDialogState.value?.let {
            ScenarioDialog(
                scenarioDialogState = scenarioDialogState,
            )
        }
    }
}